@@ -5,30 +5,24 @@ OC.L10N.register(
     "Rename" : "Renomar",
     "Move" : "Mover",
     "Delete" : "Desaniciar",
+    "Select all" : "Esbillar too",
     "New" : "Nuevu",
     "New folder" : "Carpeta nueva",
-    "Grid view" : "Vista de rexella",
-    "List view" : "Vista de llista",
-    "Select all" : "Esbillar too",
     "Submit" : "Unviar",
     "Cancel" : "Encaboxar",
     "Recent" : "Reciente",
     "Import" : "Importar",
     "Export" : "Esportar",
-    "Recently added" : "Amestao apocayá",
-    "Alphabetically" : "Alfabéticamente",
     "Clear data" : "Llimpiar datos",
     "Title" : "Títulu",
     "Link" : "Link",
     "Tags" : "Etiquetes",
-    "Attachments" : "Axuntos",
     "Notes" : "Notes",
     "Owner" : "Owner",
     "Sharing" : "Compartiendo",
     "Share link" : "Share link",
     "Copy link" : "Copiar enllaz",
     "Allow editing" : "Permitir edición",
-    "Select" : "Esbillar",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
